[PATCH] D31422: Add builder for libunwind docs

Jonathan Roelofs via Phabricator via cfe-commits cfe-commits at lists.llvm.org
Tue Mar 28 08:43:33 PDT 2017


jroelofs created this revision.

Dimitri, do you mind hosting another docs builder on your machine?


https://reviews.llvm.org/D31422

Files:
  buildbot/osuosl/master/config/builders.py
  zorg/buildbot/builders/SphinxDocsBuilder.py


Index: buildbot/osuosl/master/config/builders.py
===================================================================
--- buildbot/osuosl/master/config/builders.py
+++ buildbot/osuosl/master/config/builders.py
@@ -1353,6 +1353,13 @@
                'builddir':"libcxx-sphinx-docs",
                'factory': SphinxDocsBuilder.getSphinxDocsBuildFactory(libcxx_html=True),
                'category' : 'libcxx'
+             },
+             {
+               'name':"libunwind-sphinx-docs",
+               'slavenames':["gribozavr3"],
+               'builddir':"libunwind-sphinx-docs",
+               'factory': SphinxDocsBuilder.getSphinxDocsBuildFactory(libunwind_html=True),
+               'category' : 'libunwind'
              }
            ]
 


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D31422.93246.patch
Type: text/x-patch
Size: 2968 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/cfe-commits/attachments/20170328/71a593be/attachment.bin>


More information about the cfe-commits mailing list
Index: zorg/buildbot/builders/SphinxDocsBuilder.py
===================================================================
--- zorg/buildbot/builders/SphinxDocsBuilder.py
+++ zorg/buildbot/builders/SphinxDocsBuilder.py
@@ -11,7 +11,8 @@
         clang_html        = False, # Build Clang HTML documentation
         clang_tools_html  = False, # Build Clang Extra Tools HTML documentation
         lld_html          = False, # Build LLD HTML documentation
-        libcxx_html       = False  # Build Libc++ HTML documentation
+        libcxx_html       = False, # Build Libc++ HTML documentation
+        libunwind_html    = False  # Build libunwind HTML documentation
         ):
 
     f = buildbot.process.factory.BuildFactory()
@@ -23,6 +24,7 @@
     lld_srcdir = llvm_srcdir + '/tools/lld'
     libcxx_srcdir = llvm_srcdir + '/projects/libcxx'
     libcxxabi_srcdir = llvm_srcdir + '/projects/libcxxabi'
+    libunwind_srcdir = llvm_srcdir + '/projects/libunwind'
 
     # Get LLVM. This is essential for all builds
     # because we build all subprojects in tree
@@ -65,6 +67,13 @@
                       defaultBranch='trunk',
                       workdir=libcxxabi_srcdir))
 
+    if libunwind_html:
+        f.addStep(SVN(name='svn-libunwind',
+                      mode='update',
+                      baseURL='http://llvm.org/svn/llvm-project/libunwind/',
+                      defaultBranch='trunk',
+                      workdir=libunwind_srcdir))
+
     f.addStep(ShellCommand(name="create-build-dir",
                                command=["mkdir", "-p", llvm_objdir],
                                haltOnFailure=False, # We might of already created the directory in a previous build
@@ -132,4 +141,12 @@
                                targets=['docs-libcxx-html']
                               ))
 
+    if libunwind_html:
+        f.addStep(NinjaCommand(name="docs-libunwind-html",
+                               haltOnFailure=True,
+                               description=["Build libunwind Sphinx HTML documentation"],
+                               workdir=llvm_objdir,
+                               targets=['docs-libunwind-html']
+                              ))
+
     return f